#
# spec file for package python-reedsolo
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-reedsolo
Version:        1.7.0
Release:        1.4
Summary:        Pure-Python Reed Solomon encoder/decoder
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/tomerfiliba/reedsolomon
Source:         https://files.pythonhosted.org/packages/source/r/reedsolo/reedsolo-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
A pure-python universal errors-and-erasures Reed-Solomon Codec, based on the wonderful tutorial at Wikiversity,
written by "Bobmath" and "LRQ3000". If you are just starting with Reed-Solomon error correction codes,
the Wikiversity article is a good beginner's introduction. This is a burst-type implementation,
so that it supports any Galois field higher than 2^3, but not binary streams.

%prep
%setup -q -n reedsolo-%{version}
sed -i '/^#!/d' reedsolo.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc README.rst changelog.txt
%license LICENSE
%{python_sitelib}/*

%changelog
* Fri Dec  8 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.0:
  * Drop cythonization by default, to avoid installation issues
    for users with Cython installed but no C++ compiler.
    Cythonization needs to be requested explictly now, using `pip
    install --upgrade reedsolo --install-option="--cythonize"
  - -verbose`.
  * Clarify license to ensure Public Domain-like rights are
    granted to users, via the Unlicense or MIT-0 License at the
    user's preference (big thanks to @musicinmybrain Ben
    Beasley).
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.6.0
  Annual Christmas maintenance!
  * Changelog:
  Fix major issue preventing pip install when both Cython and a C compiler was installed (thanks to @m-rossi for the fix!)
  Fix minor inconsistency in reporting errata positions (thanks to @jbosboom!)
  Migrate continuous integration unit testing from Travis-CI (now only paid plans are offered since 2020) to GitHub Actions.
  Add CI unit testing for Python 3.7 up to 3.12 alpha 3, and PyPy 3.
  Drop CI unit testing and support for Python 3.3 to 3.6 included.
  fixes #34 uncaught error when RSCodec initialized with too many ECC symbols
  fixes #46 support for bytes input for higher galois fields (thanks to @another-pjohnson!)
  fix erasures correction for chunked messages (thanks to @another-pjohnson!)
  Fixes #44 Cythonized implementation chunking was not implemented in check method (thanks to @henla464!)
  Add note about limitation to galois field 8 of C implementation, fixes #29
  update install instructions in README.rst
  Add mention of other contributors
  If you are interested in knowing the future of this module, please read this announcement.
  Merry Christmas to everyone, may all your wishes come true!
* Tue Jun 28 2022 Torsten Gruner <simmphonie@opensuse.org>
- Initial release 1.5.4
